﻿using SharpDX.DirectInput;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;

namespace TestSharpDx
{
	public class PositionChangedEventArgs : EventArgs
	{
		private DeviceInfo sender;
		public DeviceInfo Sender { get { return sender; } set { sender = value; } }

		private JoystickOffset offset;
		public JoystickOffset Offset { get { return offset; } }

		private Int32 value;
		public Int32 Value { get { return value; } }

		public PositionChangedEventArgs(DeviceInfo _sender, JoystickOffset _offset, Int32 _value)
		{
			Debug.Assert(_offset == JoystickOffset.X || _offset == JoystickOffset.Y || _offset == JoystickOffset.Z, "Only positions here!!!");

			sender = _sender;
			offset = _offset;
			value = _value;
		}

		public override string ToString()
		{
			return String.Format("Pos {0} = {1}", offset.ToString(), value);
		}
	}

	public class DeviceChangedEventArgs : EventArgs
	{
		private DeviceInfo sender;
		public DeviceInfo Sender { get { return sender; } set { sender = value; } }

		private bool connected;
		public bool Connected { get { return connected; } }

		public DeviceChangedEventArgs(DeviceInfo _sender, bool _connected)
		{
			sender = _sender;
			connected = _connected;
		}

		public override string ToString()
		{
			return String.Format("Device: {0}", connected?"connected":"disconnected");
		}
	}


	public class SwitchChangedEventArgs : EventArgs
	{
		private DeviceInfo sender;
		public DeviceInfo Sender { get { return sender; } set { sender = value; } }

		private int pin;
		public int Pin { get { return pin; } }

		private bool pinState;
		public bool PinState { get { return pinState; } }

		public SwitchChangedEventArgs(DeviceInfo _sender, int _pin, bool _pinState)
		{
			pin = _pin;
			sender = _sender;
			pinState = _pinState;
		}

		public override string ToString()
		{
			return String.Format("PinState: {0}", pinState.ToString());
		}
	}
}
